import jinja2

class NeverUndefined(jinja2.StrictUndefined):
    def __init__(self, *args, **kwargs):
        if len(args) == 1:
            info = args[0]
        elif "name" in kwargs:
            info = f"Undefined variable '{kwargs['name']}"
        else:
            info_list = ["Not allowing any undefined variable."]
            info_list.append(f"ARGS: {args}")
            info_list.append(f"KWARGS: {kwargs}")
            info = "\n".join(info_list)
        raise Exception(info)



from setuptools import setup, find_packages

setup(
    name='jinja2_neverundefined',
    version='0.5.0',
    description='Jinja2 extension that never undefined',
    url='https://github.com/james4ever0/jinja_neverundefined',
    author='James Brown',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        'Jinja2',
    ],
)